import { writable } from "svelte/store";
import { ariaLabel } from "./internal/aria-label";
import { ariaPressed, togglePressed } from "./internal/aria-pressed";
import { applyBehaviors } from "./internal/behavior";
import { onKeyboard } from "./internal/on-keyboard";
import { onClick } from "./internal/on-click";
import { onSpaceEnter } from "./internal/on-space-enter";
import { setRole } from "./internal/set-role";
import { setTabIndex } from "./internal/set-tab-index";
import { setType } from "./internal/set-type";
const defaultState = {
    label: '',
    pressed: false,
};
export const createButtonBehaviors = (store) => {
    const toggle = togglePressed(store);
    return [
        setType('button'),
        setRole('button'),
        setTabIndex(),
        ariaLabel(store),
        ariaPressed(store),
        onClick(toggle),
        onSpaceEnter(toggle),
    ];
};
export function createButton(state) {
    const store = writable({ ...defaultState, ...state });
    function button(node) {
        const unsubscribe = applyBehaviors(node, createButtonBehaviors(store));
        return {
            destroy() {
                unsubscribe && unsubscribe();
            },
        };
    }
    const { subscribe } = store;
    return {
        state: { subscribe },
        button,
    };
}
