import { writable } from "svelte/store";
import { ariaChecked, toggleChecked } from "./internal/aria-checked";
import { ariaLabel } from "./internal/aria-label";
import { applyBehaviors } from "./internal/behavior";
import { onClick } from "./internal/on-click";
import { onSpaceEnter } from "./internal/on-space-enter";
import { setRole } from "./internal/set-role";
import { setTabIndex } from "./internal/set-tab-index";
import { setType } from "./internal/set-type";
const defaultState = {
    label: '',
    checked: false,
};
export const createSwitchBehaviors = (store) => {
    const toggle = toggleChecked(store);
    return [
        setType('button'),
        setRole('switch'),
        setTabIndex(),
        ariaLabel(store),
        ariaChecked(store),
        onClick(toggle),
        onSpaceEnter(toggle),
    ];
};
export function createSwitch(state) {
    const store = writable({ ...defaultState, ...state });
    function toggleSwitch(node) {
        const unsubscribe = applyBehaviors(node, createSwitchBehaviors(store));
        return {
            destroy() {
                unsubscribe && unsubscribe();
            },
        };
    }
    const { subscribe } = store;
    return {
        state: { subscribe },
        toggleSwitch,
    };
}
